﻿// BetterRandomRectangles (c) 2009 by Charles Petzold
using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Shapes;
using System.Windows.Media.Imaging;

namespace BetterRandomRectangles
{
    public partial class MainPage : UserControl
    {
        Random rand = new Random();
        ulong count = 0;
        WriteableBitmap bitmap;

        public MainPage()
        {
            InitializeComponent();
            CompositionTarget.Rendering += OnRendering;
        }

        void OnGridSizeChanged(object sender, SizeChangedEventArgs args)
        {
            if (args.NewSize.IsEmpty)
                return;

            bitmap = new WriteableBitmap((int)args.NewSize.Width, 
                                         (int)args.NewSize.Height);
            img.Source = bitmap;
            count = 0;
        }

        void OnRendering(object sender, EventArgs args)
        {
            if (bitmap == null)
                return;

            int width = bitmap.PixelWidth;
            int height = bitmap.PixelHeight;

            int x1 = rand.Next(width);
            int x2 = rand.Next(width);
            int y1 = rand.Next(height);
            int y2 = rand.Next(height);

            byte[] bytes = new byte[4];
            rand.NextBytes(bytes);
            Color clr = Color.FromArgb(bytes[0], bytes[1], 
                                       bytes[2], bytes[3]);

            Path path = new Path()
            {
                Fill = new SolidColorBrush(clr),
                Data = new RectangleGeometry()
                {
                    Rect = new Rect(Math.Min(x1, x2), 
                                    Math.Min(y1, y2),
                                    Math.Abs(x1 - x2), 
                                    Math.Abs(y1 - y2))
                }
            };

            path.Measure(new Size(width, height));
            path.Arrange(new Rect(new Point(), path.DesiredSize));

            bitmap.Render(path, null);
            bitmap.Invalidate();
            txt.Text = (++count).ToString();
        }
    }
}
